@@ -13,17 +13,20 @@ def agrega_categoria_entropia(diccionario_entropia, categoria, datos):
         diccionario_entropia[categoria] = st.entropy(nuevos_datos)
     print("Nuevo diccionario: ", diccionario_entropia)
 
-def agrega_categoria_entropia_aproximada(diccionario_entropia, categoria, datos, tamanio_vectorial, traslape):
-    print("Agrego categoria de entropia: ")
+def agrega_categoria_entropia_aproximada(diccionario_entropia,
+                                         categoria,
+                                         datos,
+                                         tamanio_vectorial,
+                                         traslape):
+    print("Agrego categoria de entropia aproximada: ")
     print("--------------------------------------------------------------")
     print("Diccionario:", diccionario_entropia)
     print("Categoria", categoria)
     print("Datos:", datos)
     nuevos_datos = np.array(datos)
     if categoria not in diccionario_entropia:
-        diccionario_entropia[categoria] = calcula_entropia_aproximada(nuevos_datos,
-                                                                      tamanio_vectorial,
-                                                                      traslape)
+        print("Procesando informacion")
+        diccionario_entropia[categoria] = ApEn(nuevos_datos, tamanio_vectorial, traslape)
     print("Nuevo diccionario: ", diccionario_entropia)
 
 
@@ -58,22 +61,20 @@ def calcula_divergencias_de_lista_arreglos(lista_arreglos):
     return resultados_divergencia
 
 
-def calcula_entropia_aproximada(arreglo, m, r) -> float:
+def ApEn(U, m, r) -> float:
+    """Approximate_entropy."""
 
     def _maxdist(x_i, x_j):
         return max([abs(ua - va) for ua, va in zip(x_i, x_j)])
 
     def _phi(m):
-        x = [[arreglo[j] for j in range(i, i + m - 1 + 1)] for i in range(n - m + 1)]
-        c = [
-            len([1 for x_j in x if _maxdist(x_i, x_j) <= r]) / (n - m + 1.0)
+        x = [[U[j] for j in range(i, i + m - 1 + 1)] for i in range(N - m + 1)]
+        C = [
+            len([1 for x_j in x if _maxdist(x_i, x_j) <= r]) / (N - m + 1.0)
             for x_i in x
         ]
-        return (n - m + 1.0) ** (-1) * sum(np.log(c))
-
-    n = len(arreglo)
-
-    return _phi(m) - _phi(m + 1)
-
+        return (N - m + 1.0) ** (-1) * sum(np.log(C))
 
+    N = len(U)
 
+    return _phi(m) - _phi(m + 1)
\ No newline at end of file
