@@ -314,13 +314,13 @@ class Experimento:
                                                              self.posiciones_y)
         self.velocidad_maxima = round(self.serie_velocidad.max(), 3)
 
-        self.serie_aceleracion = m_vel.calcula_serie_aceleracion(arreglo_tiempo=self.tiempo,
-                                                                 serie_velocidad=self.serie_velocidad)
-
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="velocidad",
                                            serie=self.serie_velocidad)
 
+        self.serie_aceleracion = m_vel.calcula_serie_aceleracion(arreglo_tiempo=self.tiempo,
+                                                                 serie_velocidad=self.serie_velocidad)
+
         self.aceleracion_maxima = round(self.serie_aceleracion.max(), 3)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
@@ -335,7 +335,7 @@ class Experimento:
 
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_velocidad",
-                                                  datos=self.serie_velocidad,
+                                                  datos=self.serie_velocidad.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
                                                   traslape=traslape)
 
@@ -345,7 +345,7 @@ class Experimento:
 
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_aceleracion",
-                                                  datos=self.serie_aceleracion,
+                                                  datos=self.serie_aceleracion.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
                                                   traslape=traslape)
 
